# Setup
options(scipen=999)
library(ggplot2)
data("midwest", package = "ggplot2")
theme_set(theme_bw())
theme_update(plot.title = element_text(hjust = 0.5))


g_agent_prey <- ggplot(with_agent, aes(x=with_agent$ID, y=with_agent$`N-Prey`)) + 
  geom_point(aes(col=with_agent$`Name-SS`, size=with_agent$`N-Prey`)) + 
  geom_smooth(method="loess", se=F) + xlim(c(0, 500)) + ylim(c(0, 2500)) + 
  labs(title="Time vs Prey population", y="Population", x="Time")

g_agent_predator <- ggplot(with_agent, aes(x=with_agent$ID, y=with_agent$`N-Predator`)) + 
  geom_point(aes(col=with_agent$`Name-SS`, size=with_agent$`N-Predator`)) + 
  geom_smooth(method="loess", se=F) + xlim(c(0, 500)) + ylim(c(0, 2500)) + 
  labs(title="Time vs Predator population", y="Population", x="Time")

g_noagent_prey <- ggplot(without_agent, aes(x=without_agent$ID, y=without_agent$`N-Prey`)) + 
  geom_point(aes(col=without_agent$`Name-SS`, size=without_agent$`N-Prey`)) + 
  geom_smooth(method="loess", se=F) + xlim(c(0, 500)) + ylim(c(0, 2500)) + 
  labs(title="Time vs Prey population", y="Population", x="Time")

g_noagent_predator <- ggplot(without_agent, aes(x=without_agent$ID, y=without_agent$`N-Predator`)) + 
  geom_point(aes(col=without_agent$`Name-SS`, size=without_agent$`N-Predator`)) + 
  geom_smooth(method="loess", se=F) + xlim(c(0, 500)) + ylim(c(0, 2500)) + 
  labs(title="Time vs Predator population", y="Population", x="Time")

g_agent_prey
g_agent_predator
g_noagent_prey
g_noagent_predator

#histogram with density
histo_noagent_prey <- ggplot(data=without_agent, aes(`N-Prey`)) +
  geom_histogram( aes(`N-Prey`, ..density.., color=`Name-SS`), fill="white" ) +
  geom_density( aes(`N-Prey`, ..density.., color=`Name-SS`) ) +
  geom_rug( aes(`N-Prey`, color=`Name-SS`) ) +
  #facet_grid(Search ~ ., scales="free") +
  facet_wrap(~`Name-SS`, ncol = 3) +
  xlab("Number of preys") +
  ylab("Density") +
  guides(colour = guide_legend(nrow = 1)) + 
  theme(legend.position = "bottom", legend.direction = "horizontal", legend.box = "horizontal", legend.key.size = unit(0.5, "cm"))

histo_noagent_predator <- ggplot(data=without_agent, aes(`N-Predator`)) +
  geom_histogram( aes(`N-Predator`, ..density.., color=`Name-SS`), fill="white") +
  geom_density( aes(`N-Predator`, ..density.., color=`Name-SS`) ) +
  geom_rug( aes(`N-Predator`, color=`Name-SS`) ) +
  #facet_grid(Search ~ ., scales="free") +
  facet_wrap(~`Name-SS`, ncol = 3) +
  xlab("Number of predators") +
  ylab("Density") +
  guides(colour = guide_legend(nrow = 1)) + 
  theme(legend.position = "bottom", legend.direction = "horizontal", legend.box = "horizontal", legend.key.size = unit(0.5, "cm"))

histo_agent_prey <- ggplot(data=with_agent, aes(`N-Prey`)) +
  geom_histogram( aes(`N-Prey`, ..density.., color=`Name-SS`), fill="white" ) +
  geom_density( aes(`N-Prey`, ..density.., color=`Name-SS`) ) +
  geom_rug( aes(`N-Prey`, color=`Name-SS`) ) +
  #facet_grid(Search ~ ., scales="free") +
  facet_wrap(~`Name-SS`, ncol = 3) +
  xlab("Number of preys") +
  ylab("Density") +
  guides(colour = guide_legend(nrow = 1)) + 
  theme(legend.position = "bottom", legend.direction = "horizontal", legend.box = "horizontal", legend.key.size = unit(0.5, "cm"))

histo_agent_predator <- ggplot(data=with_agent, aes(`N-Predator`)) +
  geom_histogram( aes(`N-Predator`, ..density.., color=`Name-SS`), fill="white") +
  geom_density( aes(`N-Predator`, ..density.., color=`Name-SS`) ) +
  geom_rug( aes(`N-Predator`, color=`Name-SS`) ) +
  #facet_grid(Search ~ ., scales="free") +
  facet_wrap(~`Name-SS`, ncol = 3) +
  xlab("Number of predators") +
  ylab("Density") +
  guides(colour = guide_legend(nrow = 1)) + 
  theme(legend.position = "bottom", legend.direction = "horizontal", legend.box = "horizontal", legend.key.size = unit(0.5, "cm"))

histo_noagent_prey
histo_noagent_predator
histo_agent_prey
histo_agent_predator
